#!/bin/sh

[ "`which wget`" = "" ] && echo "The tool wget to download the software is missing!" && exit 1

check_for_presence()
{
	if [ ! -s $1 ];	then
		echo 'Download was unsuccesful.'
	fi 
}	 

# Download libsvm
printf "\nDownloading SVM library\n"
wget -O 'libsvm.tar.gz' 'https://www.csie.ntu.edu.tw/~cjlin/libsvm/libsvm-3.32.tar.gz'
check_for_presence libsvm.tar.gz

# Download Glimmer
printf "\nDownloading Glimmer3\n"
wget -O 'glimmer.tar.gz' 'https://ccb.jhu.edu/software/glimmer/glimmer302b.tar.gz' 
check_for_presence glimmer.tar.gz 

# Download librf
printf "\nDownloading random forests library\n"
wget -O 'librf.tar.gz' 'https://storage.googleapis.com/google-code-archive-downloads/v2/code.google.com/librf/librf.0.1.tar.gz'
check_for_presence librf.tar.gz

# Download Kohonen's LVQ_PAK
printf "\nDownloading Kohonen's learning vector quantization package\n"
wget -O 'lvq_pak.tar' 'http://www.cis.hut.fi/research/lvq_pak/lvq_pak-3.1.tar' 
check_for_presence lvq_pak.tar

# Download Blast executables
os=`uname -a`
os=`echo $os | tr '[:upper:]' '[:lower:]'`
if [[ $os =~ linux ]] 
then 
	printf "\nDownloading 64-bit Blast 2.2.26 executables (for blastclust)\n"
	wget -O 'blast.tar.gz' 'https://ftp.ncbi.nlm.nih.gov/blast/executables/legacy.NOTSUPPORTED/2.2.26/blast-2.2.26-x64-linux.tar.gz' 
	check_for_presence blast.tar.gz
elif [[ $os =~ freebsd ]] 
then
	printf "\nDownloading 32-bit Blast 2.2.26 executables (for blastclust)\n"
	wget -O 'blast.tar.gz' 'https://ftp.ncbi.nlm.nih.gov/blast/executables/legacy.NOTSUPPORTED/2.2.26/blast-2.2.26-ia32-freebsd.tar.gz' 
	check_for_presence blast.tar.gz
elif [[ $os =~ sunos || $os =~ solaris ]] 
then
	printf "\nDownloading 64-bit Blast 2.2.26 exectutables (for blastclust)\n"
	if [[ $os =~ sparc ]]
	then
		wget -O 'blast.tar.gz' 'https://ftp.ncbi.nlm.nih.gov/blast/executables/legacy.NOTSUPPORTED/2.2.26/blast-2.2.26-sparc64-solaris.tar.gz'	
	else 
		wget -O 'blast.tar.gz' 'https://ftp.ncbi.nlm.nih.gov/blast/executables/legacy.NOTSUPPORTED/2.2.26/blast-2.2.26-x64-solaris.tar.gz'
	fi 
	check_for_presence blast.tar.gz
elif [[ $os =~ darwin ]] 
then 
	printf "\nDownloading Blast 2.2.26 executables (for blastclust)\n"
	wget -O 'blast.tar.gz' 'https://ftp.ncbi.nlm.nih.gov/blast/executables/legacy.NOTSUPPORTED/2.2.26/blast-2.2.26-universal-macosx.tar.gz' 
	check_for_presence blast.tar.gz
elif [[ $os =~ cygwin ]]
then
	printf "\nDownloading 64-bit Blast 2.2.26 executables (for blastclust)\n"
	wget -O 'blast.win64.exe' 'https://ftp.ncbi.nlm.nih.gov/blast/executables/legacy.NOTSUPPORTED/2.2.26/blast-2.2.26-x64-win64.exe' 
	check_for_presence blast.win64.exe
else
	printf 'Prebuilt blastclust binaries are probably unavailable for your system. If you want to build classifiers, and not just test repeats, check the NCBI homepage for blastclust sources.\n'
fi
